==> libflickr_0.1-2.tar.gz: libflickr-0.1/src/driver_config.h <==
/*
 * config.h - methods and constants for driver
 * This file is part of MySocials driver library
 *
 * Copyright (C) 2010 - MySocials team
 *
 * libvkontakte library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * libvkontakte library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with libvkontakte library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */
#ifndef _DRIVER_CONFIG_H_
#define _DRIVER_CONFIG_H_

//settings
#define DRIVER_ID "flickr"
#define DRIVER_NAME "Flickr"

#define DRIVER_PIC "\
iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAACXBIWXMAAAsTAAALEwEAmpw\
YAAADFWlDQ1BQaG90b3Nob3AgSUNDIHByb2ZpbGUAAHjajZRPaBxVHMc/bzqhUBKhuLYhoD\
w8pKEkYWwFtwg12STdxizrMk2aPxRkM/t2d8zL7PhmdmtLEQlIj209ipf+oXgo4kly8ODJHk\
QC1uolCB6rCMVCL1LWw+yfCW1pfzDweb/f731/fwYeDHxbDkNtS\
dgMYuPmc3JldU3u/4UBhhgEKHtROF0qFQDKYajZawIe/4YAuDfxjPiLbMisrK6BkECmlvDbQ\
GY94dNA5nwcxiDOARmvXq6ACIFxs+jOgPgKeKWW4vUUV1TkwcAU0PBCE4OVAbI\
trxaDuAM4QcUPQOwC2UrkbYJVAOvfldU1mbQZL8DJ12HfT33fWgR3bsPh0b5vbBheW4bt433f\
IxcBiEM7UfX4sWRrgzkY+KPdfjQK+7+AJ9fa7f9utNtPbsK+XfhBe03T6u5Y/AxJv92db7tde\
h4nMwGQheunYfkALHwOX/4JR76BV7+D0hAsnsD6jO4Xq09igJlGeMH4tXosjznOO3I6DLWS84\
E3OS7LWkvj1+pxJI2KlGmpyiSbuul16h0EBlWwdAYYBetTFc11WGxVyrMLwCSIvypqdg4YB/F1\
1T81D4wBu1VzailhcdSP5xcTts4Guljo8HCwXvygo2mHcc7t6ketM3Nd/0fl90vACAh3o7HgAo\
fAmrpYX1xOWOiL9Zlih381TXcJeBOsW6EuFZLerB9ZRaPwCVAESFzy5JggxNCgio+PxiePIkBh\
8InYeGamppRiSZ4HBDzA4PMxTRQSl7PkimyN9xSk87vzj3Pfue7ccv6+OtIc60e2zIe+t3PlIS\
UUpqfbiXZ6SvQ9Gkyj0dRQbPZmilKdprqrBldH+krezpWH6nLxcWpKlao0wTqKiA0MPi0UmgjF\
dKra87an0HcvfT/cr3Xf3j53b/DupT27ajw1lepNtffcz0vfV/Yb9lv2vJ21TyDt9+wp+6Q9a2\
ftd+1C78YSAT7nURgiymgCLiD3/L9uLsnbAkAmrwJlfE+6+ZwsmUbV1yr1zL0g/JL2P7hwD\
d9vKXrGAAAAIGNIUk0AAG2YAABzjgAA8k4AAIUeAABujgAA5T0AADMuAAAY0b0SiH8AAAiqSUR\
BVHja5Jvvb1tXGcc/5147jn8kbUyb9Vea/tiytawMREXLRCXaMiFAG1M3ba0EGhV/QCWE9gaJF\+UFQnuDhMQbhPYCjf0I0KRkiGijIIZaSAaikbaUNA1L1iZNmsazYzv29T3n8OJeO7ZzHd+4VErc\
Ez2KfOOce57vfZ7v8+OeI7TWPMjD4AEfJQCEEF4ihBBmMpl8wbKsC0qpUUCvd1FKjVqWdSGZTL4\
ghDBdPSp0Kw2tNR5uIABzfHz8sGVZI0opXZTiKL92P2Ut9/Jam2VZI+Pj44cB09WrQm9RVL4MFQ\
GYN27c+Ep3d/dvhBDRCsQ20BBCoJRCa52ZnJx8fv/+/e8C0tFf1+QAY3Bw8EBXV9dbQF\
QIUUJro4lSqvhgo11dXW8NDg4eqNa52gIMILywsPD79vb244Zh0AxRomgJqVTqz/F4/GlgSWutq\
i1AAMHe3t4jsVjs+EZ+8l4ihCAWix3v7e09AgSLSgeqAAj19PQ8vQo5bshRBADA1e99IF8NgAlEIpHI4\
80GQPlw9YsAqWoXMIFwMBjs3Kis74cLgsFgJxD2cgETCEkpQ0qpkuk0k/IAUsoQEPICwAACSqlSZGhG\
F1BKiXK9q0nQUEo2OQBSlLt+oNpSlFomv+YEQFOeEgc8ggZujtBkAIiSfuUj4IWQi1KTkWCFBdQGQCvlSJOZv3Y\
jgXYjXG0L0BpZ9aXmQUGjdF0XUKhmBcDVb3UX0HqFmTSXEdTjAK1QujEAppNw6bpkdnH5Joe2G3xx\
r0FbaG1zBSZStLw3jTmfK12zDndiHd6KjgbvAYB6HFAWBfyOqYTm53+zufLRSuD6RiAUgFOfCXD2i\
EkoUF/xtp9epeXq/Iq/tfZNoMMBMqcfIfutHnTAaMAFfHCAlBK/BdHwx4ofvC1Zsmp/x5bwq2Gbyx\
OSV5412Rr1njv8zk02/eSfiHxtCxSLFrFffEDoygwLPz6K2hxak/lXc4DhBYBt2yUyXE0+mJG83G+T\
zmukri9j84rvXbBJ51fOFfzHbTafH0JkbZCqrgSvztPx8hW05W+t5XqtCoBWCiUl0raXcwIPsaXi/K\
AkYzlP2K/8Z07zyyuyYi4yFh3n34e8Alv7lpZ/zxN9bWzVdRZF2jZKyvp5gEajtEJJhaGNmq7w7hhc\
n2+MiH79L82Zz8Fmtypv/90E5ky2obnaXr1G6tQeVNj0ZfqaNeQBSikMwxuEP1wTSNVY40QqeGdM89\
whZzGRSzediw0MI2kR+us0mad2+vL7unlAdRRQyiFEw6j0lmuzAqkaT5cn5pcZuWUkAbLxuQLjKdTJ\
HZ5JT3Xc9xUFvDLB4rWiNcwuGtj3kC/NpZ1oY6YKiCX7npIbcy6LlHJFsuNVz/iwgNVT4eK7tXBAk8s\
13jsMmY5pqrDhlCr3YAEyZFDexlutkKsLAHVS4eLUW6ImcxkTo0EMujZJlPvUrC2ttExnGwYgv6sVaf\
u0oipwjFoWUE+e3G1j2RrL1hSkw2FK+5ejXcvxO3Wsc23/rLRzw4JC24rkF7b4XrevRMiPnDpoEQlqd\
y2agnTEliAlKFVbPr9Dsm/zMgB3n+9Cm8Kf0rajOAUnIfrkqW3kHwr9HwFwi6F6Eg9Lzj2ZW2Fdys36\
bOWIVJXZYCSo+P6XMkglS5Ld2crt7+wrU7RcXKVt5XxWumTGdkcLt8496nvNyqPQqxEG/dH7cwdzTH0\
ieO1q6+qc4bpdKKA5fzJD9yab6ltMf3cvof8uEv/jjL+iJmJy45XPkt/SAmso3+u3xPTaGiLnjmbYvU\
nys79HSFu1GXFvh+SHX07z6U675npvnH+c7P4YO16dwMjKmnNle9qY+NEhlvZG16S8r3JYK41eY4Lz7\
KNLnNiT47cfhhm6FWR8IUAqL9jRJtkfl5zcm+erD+cxBNRrNUx/u5s7X99OZ99N2ocWiIwtYi5Jcrsi\
ZHti3P3adhLHthb9de39AHWfWmKxILz0RJqXnqjtC37Xm+8I8PHZPXB2Ty07vn8tsWL62IwvRYobJep\
0hR2mbEoAEPWjQPn+mmYbXlt+PEmwuOOu2V6Pa+2TBIsW0GwAGL5IUCu0+9Noe3y9+r8hDB8coDQC0VA\+sK4BMITj1nVdQGsQzu9msgC0KOlVtx8gEG5foIlCodDg6lWXAxA0HQcYGAiBPw4whOHpLxs5AqDBEEZ\
9DnCqJY1hCJztMs0AgsA0Dcq3/9QCQGey2WTBlgSCQZZyuaYAwBCCQDCILSWZbDZZ1tqsAEADOpVMzS9\
ls3TE42TSGWxpb3gAzGCAUEuIRCJBKpmaLwfAqAJADg0PD+XzedCacDhcUR9s1F3ikXCYQ\
qFAPp9naHh4COfQxAoAbMAaGBgYSSQWZufm5ujo6CAUain5zkYT0ITDrcRiMe7enSeRWJgdGBgYASwvA\
CSwZFlWoq+/v69QsPTs7G22bdtOOBxmo50fcM8HsHVrJzMz00gpdV9/f59lWQlgyYsDJJAFFvr7L17et\
XNnz4kTJ47funWLrt1dpNNp0ouL5HI5bNtel+To7gantbWV9vZ2WkIhpqYmKRQKXLp06S/9/RcvAwuun\
m5+tHxkRuDsou4EeoCDZ86c/sY3n3nmZDAYNOPxOB0dcQzTyRE8+wWisvhY2RXTntcRLgOJshJce/+9g\
rGqPpum6b7al9y5c4dUKoVt27L/4sU/vf76G28DHwJjwJzWOlcNADhb5qPADuAR4OHu7t09p1988diBA\
wf2RaPR8EZh/kwmszQ6Ojrxxptvvjc5OTUGjAPXgWkgo7WWXgAUt5K3AduAPcBu1yraDzz22LZIJBKqw\
n7dlT3ZbDY/eu3abZxTIXPAFPARcBtYBOziubla5wYDQAz4FPCQK3HXOlrWOwAuy2dcf5915S6QdqNd6\
dygFwBFEEyg1VV6kwtIGOfE1Xo+c6yAgsv0aSDpgpFziV4Xc5sKAB7U8cCfHv/fAJMxjRfE3XYHAAAAA\
ElFTkSuQmCC="

#define SECRET "c1bab398ab846d62"

#define LOGIN_SUCCESS "^http://www\\.flickr\\.com/services/auth/|^http://www\\.flickr\\.com/"

#define AUTH_REQUEST "<Request class='system' function='getFrob'><Params/></Request>"

#define MSG_AUTH_SUCCESS "<rsp><status>authorized</status></rsp>"

#define MSG_AUTH_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_AUTH_ERROR_CODE"\" msg=\""DRV_AUTH_ERROR"\"/></rsp>"

#define MSG_NETWORK_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_NETW_ERROR_CODE"\" msg=\""DRV_NETW_ERROR"\"/></rsp>"

#define MSG_NETWORK_SERVER_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_SERVER_ERROR_CODE"\" msg=\""DRV_SERVER_ERROR"\"/></rsp>"

#define MSG_INFO "<info></info>"

#define MSG_SETTINGS_SAVED_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_SETT_ERROR_CODE"\" msg=\""DRV_SETT_ERROR"\"/></rsp>"

#define MSG_FILE_SAVE_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_FILE_SAVE_ERROR_CODE"\" msg=\""DRV_FILE_SAVE_ERROR"\"/></rsp>"

#define NOT_USE_DEFAULT_WEBAUTH_PARSER
#define NOT_USE_DEFAULT_PROCESS_URL

#endif

==> libflickr_0.1-4.tar.gz: libflickr-0.1/src/driver_config.h <==
/*
 * config.h - methods and constants for driver
 * This file is part of MySocials driver library
 *
 * Copyright (C) 2010 - MySocials team
 *
 * libvkontakte library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * libvkontakte library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with libvkontakte library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */
#ifndef _DRIVER_CONFIG_H_
#define _DRIVER_CONFIG_H_

//settings
#define DRIVER_ID "flickr"
#define DRIVER_NAME "Flickr"

#define DRIVER_PIC "\
iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAACXBIWXMAAAsTAAALEwEAmpw\
YAAADFWlDQ1BQaG90b3Nob3AgSUNDIHByb2ZpbGUAAHjajZRPaBxVHMc/bzqhUBKhuLYhoD\
w8pKEkYWwFtwg12STdxizrMk2aPxRkM/t2d8zL7PhmdmtLEQlIj209ipf+oXgo4kly8ODJHk\
QC1uolCB6rCMVCL1LWw+yfCW1pfzDweb/f731/fwYeDHxbDkNtS\
dgMYuPmc3JldU3u/4UBhhgEKHtROF0qFQDKYajZawIe/4YAuDfxjPiLbMisrK6BkECmlvDbQ\
GY94dNA5nwcxiDOARmvXq6ACIFxs+jOgPgKeKWW4vUUV1TkwcAU0PBCE4OVAbI\
trxaDuAM4QcUPQOwC2UrkbYJVAOvfldU1mbQZL8DJ12HfT33fWgR3bsPh0b5vbBheW4bt433f\
IxcBiEM7UfX4sWRrgzkY+KPdfjQK+7+AJ9fa7f9utNtPbsK+XfhBe03T6u5Y/AxJv92db7tde\
h4nMwGQheunYfkALHwOX/4JR76BV7+D0hAsnsD6jO4Xq09igJlGeMH4tXosjznOO3I6DLWS84\
E3OS7LWkvj1+pxJI2KlGmpyiSbuul16h0EBlWwdAYYBetTFc11WGxVyrMLwCSIvypqdg4YB/F1\
1T81D4wBu1VzailhcdSP5xcTts4Guljo8HCwXvygo2mHcc7t6ketM3Nd/0fl90vACAh3o7HgAo\
fAmrpYX1xOWOiL9Zlih381TXcJeBOsW6EuFZLerB9ZRaPwCVAESFzy5JggxNCgio+PxiePIkBh\
8InYeGamppRiSZ4HBDzA4PMxTRQSl7PkimyN9xSk87vzj3Pfue7ccv6+OtIc60e2zIe+t3PlIS\
UUpqfbiXZ6SvQ9Gkyj0dRQbPZmilKdprqrBldH+krezpWH6nLxcWpKlao0wTqKiA0MPi0UmgjF\
dKra87an0HcvfT/cr3Xf3j53b/DupT27ajw1lepNtffcz0vfV/Yb9lv2vJ21TyDt9+wp+6Q9a2\
ftd+1C78YSAT7nURgiymgCLiD3/L9uLsnbAkAmrwJlfE+6+ZwsmUbV1yr1zL0g/JL2P7hwD\
d9vKXrGAAAAIGNIUk0AAG2YAABzjgAA8k4AAIUeAABujgAA5T0AADMuAAAY0b0SiH8AAAiqSUR\
BVHja5Jvvb1tXGcc/5147jn8kbUyb9Vea/tiytawMREXLRCXaMiFAG1M3ba0EGhV/QCWE9gaJF\+UFQnuDhMQbhPYCjf0I0KRkiGijIIZaSAaikbaUNA1L1iZNmsazYzv29T3n8OJeO7ZzHd+4VErc\
Ez2KfOOce57vfZ7v8+OeI7TWPMjD4AEfJQCEEF4ihBBmMpl8wbKsC0qpUUCvd1FKjVqWdSGZTL4\
ghDBdPSp0Kw2tNR5uIABzfHz8sGVZI0opXZTiKL92P2Ut9/Jam2VZI+Pj44cB09WrQm9RVL4MFQ\
GYN27c+Ep3d/dvhBDRCsQ20BBCoJRCa52ZnJx8fv/+/e8C0tFf1+QAY3Bw8EBXV9dbQF\
QIUUJro4lSqvhgo11dXW8NDg4eqNa52gIMILywsPD79vb244Zh0AxRomgJqVTqz/F4/GlgSWutq\
i1AAMHe3t4jsVjs+EZ+8l4ihCAWix3v7e09AgSLSgeqAAj19PQ8vQo5bshRBADA1e99IF8NgAlEIpHI4\
80GQPlw9YsAqWoXMIFwMBjs3Kis74cLgsFgJxD2cgETCEkpQ0qpkuk0k/IAUsoQEPICwAACSqlSZGhG\
F1BKiXK9q0nQUEo2OQBSlLt+oNpSlFomv+YEQFOeEgc8ggZujtBkAIiSfuUj4IWQi1KTkWCFBdQGQCvlSJOZv3Y\
jgXYjXG0L0BpZ9aXmQUGjdF0XUKhmBcDVb3UX0HqFmTSXEdTjAK1QujEAppNw6bpkdnH5Joe2G3xx\
r0FbaG1zBSZStLw3jTmfK12zDndiHd6KjgbvAYB6HFAWBfyOqYTm53+zufLRSuD6RiAUgFOfCXD2i\
EkoUF/xtp9epeXq/Iq/tfZNoMMBMqcfIfutHnTAaMAFfHCAlBK/BdHwx4ofvC1Zsmp/x5bwq2Gbyx\
OSV5412Rr1njv8zk02/eSfiHxtCxSLFrFffEDoygwLPz6K2hxak/lXc4DhBYBt2yUyXE0+mJG83G+T\
zmukri9j84rvXbBJ51fOFfzHbTafH0JkbZCqrgSvztPx8hW05W+t5XqtCoBWCiUl0raXcwIPsaXi/K\
AkYzlP2K/8Z07zyyuyYi4yFh3n34e8Alv7lpZ/zxN9bWzVdRZF2jZKyvp5gEajtEJJhaGNmq7w7hhc\
n2+MiH79L82Zz8Fmtypv/90E5ky2obnaXr1G6tQeVNj0ZfqaNeQBSikMwxuEP1wTSNVY40QqeGdM89\
whZzGRSzediw0MI2kR+us0mad2+vL7unlAdRRQyiFEw6j0lmuzAqkaT5cn5pcZuWUkAbLxuQLjKdTJ\
HZ5JT3Xc9xUFvDLB4rWiNcwuGtj3kC/NpZ1oY6YKiCX7npIbcy6LlHJFsuNVz/iwgNVT4eK7tXBAk8s\
13jsMmY5pqrDhlCr3YAEyZFDexlutkKsLAHVS4eLUW6ImcxkTo0EMujZJlPvUrC2ttExnGwYgv6sVaf\
u0oipwjFoWUE+e3G1j2RrL1hSkw2FK+5ejXcvxO3Wsc23/rLRzw4JC24rkF7b4XrevRMiPnDpoEQlqd\
y2agnTEliAlKFVbPr9Dsm/zMgB3n+9Cm8Kf0rajOAUnIfrkqW3kHwr9HwFwi6F6Eg9Lzj2ZW2Fdys36\
bOWIVJXZYCSo+P6XMkglS5Ld2crt7+wrU7RcXKVt5XxWumTGdkcLt8496nvNyqPQqxEG/dH7cwdzTH0\
ieO1q6+qc4bpdKKA5fzJD9yab6ltMf3cvof8uEv/jjL+iJmJy45XPkt/SAmso3+u3xPTaGiLnjmbYvU\
nys79HSFu1GXFvh+SHX07z6U675npvnH+c7P4YO16dwMjKmnNle9qY+NEhlvZG16S8r3JYK41eY4Lz7\
KNLnNiT47cfhhm6FWR8IUAqL9jRJtkfl5zcm+erD+cxBNRrNUx/u5s7X99OZ99N2ocWiIwtYi5Jcrsi\
ZHti3P3adhLHthb9de39AHWfWmKxILz0RJqXnqjtC37Xm+8I8PHZPXB2Ty07vn8tsWL62IwvRYobJep\
0hR2mbEoAEPWjQPn+mmYbXlt+PEmwuOOu2V6Pa+2TBIsW0GwAGL5IUCu0+9Noe3y9+r8hDB8coDQC0VA\+sK4BMITj1nVdQGsQzu9msgC0KOlVtx8gEG5foIlCodDg6lWXAxA0HQcYGAiBPw4whOHpLxs5AqDBEEZ\
9DnCqJY1hCJztMs0AgsA0Dcq3/9QCQGey2WTBlgSCQZZyuaYAwBCCQDCILSWZbDZZ1tqsAEADOpVMzS9\
ls3TE42TSGWxpb3gAzGCAUEuIRCJBKpmaLwfAqAJADg0PD+XzedCacDhcUR9s1F3ikXCYQ\
qFAPp9naHh4COfQxAoAbMAaGBgYSSQWZufm5ujo6CAUain5zkYT0ITDrcRiMe7enSeRWJgdGBgYASwvA\
CSwZFlWoq+/v69QsPTs7G22bdtOOBxmo50fcM8HsHVrJzMz00gpdV9/f59lWQlgyYsDJJAFFvr7L17et\
XNnz4kTJ47funWLrt1dpNNp0ouL5HI5bNtel+To7gantbWV9vZ2WkIhpqYmKRQKXLp06S/9/RcvAwuun\
m5+tHxkRuDsou4EeoCDZ86c/sY3n3nmZDAYNOPxOB0dcQzTyRE8+wWisvhY2RXTntcRLgOJshJce/+9g\
rGqPpum6b7al9y5c4dUKoVt27L/4sU/vf76G28DHwJjwJzWOlcNADhb5qPADuAR4OHu7t09p1988diBA\
wf2RaPR8EZh/kwmszQ6Ojrxxptvvjc5OTUGjAPXgWkgo7WWXgAUt5K3AduAPcBu1yraDzz22LZIJBKqw\
n7dlT3ZbDY/eu3abZxTIXPAFPARcBtYBOziubla5wYDQAz4FPCQK3HXOlrWOwAuy2dcf5915S6QdqNd6\
dygFwBFEEyg1VV6kwtIGOfE1Xo+c6yAgsv0aSDpgpFziV4Xc5sKAB7U8cCfHv/fAJMxjRfE3XYHAAAAA\
ElFTkSuQmCC="

#define SECRET "c1bab398ab846d62"

#define LOGIN_SUCCESS "^http://www\\.flickr\\.com/services/auth/|^http://www\\.flickr\\.com/"

#define AUTH_REQUEST "<Request class='system' function='getFrob'><Params/></Request>"

#define RESPONSE_EMPTY "<rsp stat=\"ok\"></rsp>"

#define MSG_AUTH_SUCCESS "<rsp><status>authorized</status></rsp>"

#define MSG_AUTH_CANCEL "<rsp stat=\"fail\"><err code=\"1"DRV_AUTH_CANCEL_CODE"\" msg=\""DRV_AUTH_CANCEL"\"/></rsp>"

#define MSG_AUTH_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_AUTH_ERROR_CODE"\" msg=\""DRV_AUTH_ERROR"\"/></rsp>"

#define MSG_NETWORK_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_NETW_ERROR_CODE"\" msg=\""DRV_NETW_ERROR"\"/></rsp>"

#define MSG_NETWORK_SERVER_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_SERVER_ERROR_CODE"\" msg=\""DRV_SERVER_ERROR"\"/></rsp>"

#define MSG_INFO "<info></info>"

#define MSG_SETTINGS_SAVED_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_SETT_ERROR_CODE"\" msg=\""DRV_SETT_ERROR"\"/></rsp>"

#define MSG_FILE_SAVE_ERROR "<rsp stat=\"fail\"><err code=\"1"DRV_FILE_SAVE_ERROR_CODE"\" msg=\""DRV_FILE_SAVE_ERROR"\"/></rsp>"

#define NOT_USE_DEFAULT_WEBAUTH_PARSER
#define NOT_USE_DEFAULT_PROCESS_URL

#endif
